@@ -10,7 +10,7 @@ logger.setLevel(logging.INFO)
 
 nh = logging.NullHandler()
 
-formatter = logging.Formatter("[%(levelname)s] %(asctime)s - %(name)s - %(message)s")
+formatter = logging.Formatter("[%(levelname)s] %(asctime)s - %(message)s")  # - %(name)s
 
 nh.setFormatter(formatter)
 
