@@ -138,6 +138,8 @@ class Classifier:
         self.logger.info("Estimating instance performance...")
         for i in range(n_iter):
             k = 0
+            if not hyper_param_optm:
+                self.logger.debug(f"Training classifier with default parameters {kwargs}")
             for train_index, test_index in kf.split(self.X, self.y):
                 k += 1
                 self.logger.info(f"Evaluating testing fold #{k}")
@@ -156,13 +158,13 @@ class Classifier:
                     clf = algo(**best_params)
                 else:
                     clf = algo(**kwargs)
-                    self.logger.debug(f"Training classifier with default parameters {kwargs}")
 
                 clf = clf.fit(X_train, y_train)
 
                 y_pred = clf.predict_proba(X_test)
                 score[test_index, i], proba[test_index, i] = self.score(metric=metric, y_true=self.y[test_index],
                                                                         y_pred=y_pred, classes_order=clf.classes_)
+                self.logger.info(f"Test fold mean accuracy: {clf.score(X_test, self.y[test_index])}")
             print_progress_bar(i + 1, n_iter, prefix='Progress', suffix=f'complete (CV {i + 1}/{n_iter})', length=30)
 
         end = time.time()
