@@ -1,19 +1,20 @@
+import argparse
+import logging
 import re
 import shutil
-import logging
-import argparse
-import pandas as pd
-from pathlib import Path
-from logging.handlers import RotatingFileHandler
+from importlib import import_module
 from inspect import signature, Parameter
+from logging.handlers import RotatingFileHandler
+from pathlib import Path
+
+import pandas as pd
 from pyispace.example import save_opts
+
 from . import integrator, log_file, formatter
 from .context import Configuration
-from .visualization import Demo, App
 from .feature_selection import featfilt
-from .app import graphene
 from .hpo import set_hyperopt_progressbar
-
+from .visualization import Demo, App
 
 _conf_file = 'config.yaml'
 
@@ -120,10 +121,9 @@ def main(args):
 
 
 def cli():
-    parser = argparse.ArgumentParser(description="PyHard - Instance Hardness Framework. \n"
-                                                 "Run 'python3 -m pyhard -h' for help with the options. \n"
-                                                 "In case of trouble, submit us an issue: "
-                                                 "https://gitlab.com/ita-ml/instance-hardness/")
+    parser = argparse.ArgumentParser(description="PyHard - Python Instance Hardness Framework. \n"
+                                                 "If you find a bug, please open an issue in our repo: "
+                                                 "https://gitlab.com/ita-ml/pyhard/-/issues")
     parser.add_argument('--no-meta', dest='meta', action='store_false',
                         help="does not generate a new metadata file; uses previously saved instead")
     parser.add_argument('--no-isa', dest='isa', action='store_false',
@@ -144,8 +144,6 @@ def cli():
     args = parser.parse_args()
     print("run 'pyhard --help' to see all options.")
 
-    # Temporary solution for known warnings
-    logging.getLogger("param").setLevel(logging.ERROR)
     if not args.graphene:
         sh = logging.StreamHandler()
         if args.verbose:
@@ -174,6 +172,7 @@ def cli():
         args.meta = False
         main(args)
     elif args.graphene:
+        graphene = import_module("pyhard.app.graphene")
         set_hyperopt_progressbar(False)
         graphene.run()
     elif args.generate:
