@@ -144,6 +144,8 @@ class App:
         self.tmpl = pn.Template(light_template)
 
         self.logger = logging.getLogger(__name__)
+        # Temporary solution for known warnings
+        logging.getLogger("param").setLevel(logging.ERROR)
 
         self.df_original = df_dataset
         self.df_metadata = df_metadata
